@@ -1,6 +1,7 @@
 /*
  * (C) 2000-2001 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
+ *			Peeter Vois <peeter@gtranslator.org>
  * 
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,6 +23,7 @@
 #define GTR_GUI_H 1
 
 #include <gtk/gtkwidget.h>
+#include <gtk/gtkeditable.h>
 
 #include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
@@ -78,16 +80,17 @@ void gtranslator_clipboard_copy(GtkWidget  *widget, gpointer useless);
 void gtranslator_clipboard_paste(GtkWidget  *widget, gpointer useless);
 void gtranslator_selection_clear(GtkWidget  *widget, gpointer useless);
 
-/*
- * Switch the view to the given view.
- */
-void gtranslator_switch_views(GtkWidget *widget, gpointer view);
-
 /*
  * A status defining callback -- now generaly defined for instance.
  */
 void gtranslator_translation_changed(GtkWidget  *widget, gpointer useless);
 
+void insert_text_handler(GtkEditable *editable, const gchar *text,
+			 gint length, gint *position, gpointer data);
+
+void delete_text_handler(GtkEditable *editable, gint start_position,
+                         gint end_position);
+
 /*
  * If TRUE, means that trans_box is being changed by program, not user
  */
