@@ -1,6 +1,7 @@
 /*
- * (C) 2000-2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2000-2002 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
+ *			Peeter Vois <peeter@gtranslator.org>
  * 
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -33,7 +34,6 @@
 #include "open.h"
 #include "parse.h"
 #include "prefs.h"
-#include "query.h"
 #include "runtime-config.h"
 #include "save.h"
 #include "session.h"
@@ -61,11 +61,12 @@
  */
 static gchar 	*gtranslator_geometry=NULL;
 static gchar 	*save_html_output_file=NULL;
-static gchar 	*domains_dir=NULL;
 static gchar	*learn_file=NULL;
 static gchar	*auto_translate_file=NULL;
+static gchar	*exporting_po_file=NULL;
 static gboolean	build_information=FALSE;
 static gboolean	no_modules=FALSE;
+gboolean 	nosyntax=FALSE;
 
 /*
  * gtranslator's option table.
@@ -83,6 +84,10 @@ static struct poptOption gtranslator_options[] = {
 		"build-information", 'b', POPT_ARG_NONE, &build_information,
 		0, N_("Show build information/specifications"), NULL
 	},
+	{
+		"export-learn-buffer", 'e', POPT_ARG_STRING, &exporting_po_file,
+		0, N_("Export learn buffer to a plain po file"), N_("PO_FILE")
+	},
 	{
 		"geometry", 'g', POPT_ARG_STRING, &gtranslator_geometry,
 		0, N_("Specify main window geometry"), N_("GEOMETRY")
@@ -95,14 +100,14 @@ static struct poptOption gtranslator_options[] = {
 		"no-modules", 'n', POPT_ARG_NONE, &no_modules,
 		0, N_("Don't load any backend modules"), NULL
 	},
-	{
-		"querydomaindir", 'q', POPT_ARG_STRING, &domains_dir,
-		0, N_("Define another query-domains directory"), N_("LOCALEDIR")
-	},
 	{
 		"webalize", 'w', POPT_ARG_STRING, &save_html_output_file,
 		0, N_("HTML file to write to"), N_("HTMLFILE")
 	},
+	{
+		"nosyntax", 'y', POPT_ARG_NONE, &nosyntax,
+		0, N_("Don't highlight syntax"), NULL 
+	},
 	POPT_AUTOHELP {NULL}
 };
 
@@ -127,6 +132,7 @@ int main(int argc, char *argv[])
 	 * Set up the signal handler.
 	 */
 	signal(SIGSEGV, gtranslator_signal_handler);
+	signal(SIGKILL, gtranslator_signal_handler);
 	signal(SIGILL, gtranslator_signal_handler);
 	signal(SIGABRT, gtranslator_signal_handler);
 	signal(SIGINT, gtranslator_signal_handler);
@@ -187,6 +193,9 @@ int main(int argc, char *argv[])
 		exit(1);
 	}
 
+	/* Initialize configuration client */
+	gtranslator_config_init();
+
 	/*
 	 * Read all of our "normal" preferences -- translator data is now
 	 *  outsourced into the GtrTranslator structure.
@@ -206,7 +215,7 @@ int main(int argc, char *argv[])
 		/*
 		 * Test first if the local libgmodule supports modules at all.
 		 */
-		if(g_module_supported()==FALSE)
+		if(!g_module_supported())
 		{
 			g_warning(_("GModule implementation doesn't support loading dynamic modules!"));
 			backends=NULL;
@@ -311,53 +320,6 @@ int main(int argc, char *argv[])
 		}
 	}
 	
-	/*
-	 * Parse the domains in the given directory or in some other logical
-	 *  manner.
-	 */
-	if(domains_dir)
-	{
-		/*
-		 * Test if the given directory is even a directory.
-		 */
-		if(g_file_test(domains_dir, G_FILE_TEST_ISDIR))
-		{
-			/*
-			 * Parse all entries from this directory.
-			 */
-			gtranslator_query_domains(domains_dir);
-		}
-	}
-	else
-	{
-		/*
-		 * Look into some other environment variables for a sane value
-		 *  for the locale directory where the .mo files are lying
-		 *   'round -- aka. "the gettext domains".
-		 */
-		gchar	*localedirectory=NULL;
-
-		gtranslator_utils_get_environment_value(
-			"GTRANSLATOR_LOCALEDIR:GNOMELOCALEDIR",
-			&localedirectory);
-
-		/*
-		 * If the found localedirectory is a directory, then we can
-		 *  really start querying all existing domains from this 
-		 *   read-in directory.
-		 */
-		if(localedirectory && 
-			g_file_test(localedirectory, G_FILE_TEST_ISDIR))
-		{
-			gtranslator_query_domains(localedirectory);
-			GTR_FREE(localedirectory);
-		}
-		else
-		{
-			gtranslator_query_domains(GNOMELOCALEDIR);
-		}
-	}
-	
 	/*
 	 * If there are any files given on command line, open them
 	 */
@@ -376,7 +338,7 @@ int main(int argc, char *argv[])
 		 */
 		gtranslator_learn_init();
 		gtranslator_open_file(auto_translate_file);
-		gtranslator_query_translate(GtrPreferences.use_learn_buffer, FALSE);
+		gtranslator_learn_autotranslate(FALSE);
 		
 		/*
 		 * If any change has been made to the po file: save it.
@@ -394,9 +356,7 @@ int main(int argc, char *argv[])
 		/*
 		 * Set up the "runtime/filename" config. key to a sane value.
 		 */
-		gtranslator_config_init();
 		gtranslator_config_set_string("runtime/filename", "--- No file ---");
-		gtranslator_config_close();
 
 		/*
 		 * Free all till now allocated stuff.
@@ -465,8 +425,8 @@ int main(int argc, char *argv[])
 	gtranslator_learn_init();
 
 	/*
-	 * Check if any filename for learning was supplied and if yes, 
-	 *  learn the file completely, shutdown the learn buffer and exit afterwards.
+	 * Check if any filename for learning was supplied and if yes, learn
+	 *  the file completely, shutdown the learn buffer & exit afterwards.
 	 */
 	if(learn_file)
 	{
@@ -485,9 +445,7 @@ int main(int argc, char *argv[])
 		/*
 		 * Set up the "runtime/filename" config. key to a sane value.
 		 */
-		gtranslator_config_init();
 		gtranslator_config_set_string("runtime/filename", "--- No file ---");
-		gtranslator_config_close();
 
 		/*
 		 * Free all till now allocated stuff.
@@ -512,7 +470,60 @@ int main(int argc, char *argv[])
 		return 0;
 	}
 	
+	/*
+	 * If we've got the task to export a learn buffer to a plain po file
+	 *  then we should do this now after all the other tasks we could have
+	 *   to have to be done (?!).
+	 */
+	if(exporting_po_file && exporting_po_file[0]!='\0')
+	{
+		gtranslator_learn_export_to_po_file(exporting_po_file);
+
+		/*
+		 * The usual free'ing orgies are now coming along...
+		 */
+		
+		gtranslator_learn_shutdown();
+
+		/*
+		 * Set up the "runtime/filename" config. key to a sane value.
+		 */
+		gtranslator_config_set_string("runtime/filename", "--- No file ---");
+
+		/*
+		 * Free all till now allocated stuff.
+		 */
+		gtranslator_translator_free(gtranslator_translator);
+		gtranslator_preferences_free();
+
+		/*
+		 * Shutdown GnomeVFS.
+		 */
+		if(gnome_vfs_initialized())
+		{
+			gnome_vfs_shutdown();
+		}
+
+		/*
+		 * Give us another small status feedback about the export.
+		 */
+		g_print(_("Exported learn buffer to `%s'.\n"), exporting_po_file);
+
+		return 0;
+	}
+	
 	gtk_widget_show_all(gtranslator_application);
+
+	/*
+	 * Create the list of colorschemes if we are starting up in a GUI.
+	 */
+	gtranslator_color_scheme_create_schemes_list();
+
+	/*
+	 * Now do also show up the full colorschemes list in the "_Settings"
+	 *  main menu.
+	 */
+	gtranslator_color_scheme_show_list();
 	
 	gtk_main();
 	return 0;
