@@ -1,6 +1,6 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
- *		Gediminas Paulauskas <menesis@gtranslator.org>
+ * (C) 2001-2002 	Fatih Demir <kabalak@gtranslator.org>
+ *			Gediminas Paulauskas <menesis@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -28,11 +28,11 @@
 #include "message.h"
 #include "parse.h"
 #include "prefs.h"
-#include "sidebar.h"
 #include "utils_gui.h"
-#include "views.h"
 
 #include "pixmaps/auto_translation.xpm"
+#include "pixmaps/copy_msgid2msgstr.xpm"
+#include "pixmaps/edit_comment.xpm"
 #include "pixmaps/query.xpm"
 #include "pixmaps/query_big.xpm"
 
@@ -45,7 +45,6 @@
 GnomeUIInfo the_menus[] = {
 	GNOMEUIINFO_MENU_FILE_TREE(the_file_menu),
 	GNOMEUIINFO_MENU_EDIT_TREE(the_edit_menu),
-	GNOMEUIINFO_MENU_VIEW_TREE(the_views_menu),
 	GNOMEUIINFO_SUBTREE(N_("_Messages"), the_messages_menu),
 	GNOMEUIINFO_SUBTREE(N_("Mess_age status"), the_msg_status_menu),
 	GNOMEUIINFO_MENU_SETTINGS_TREE(the_settings_menu),
@@ -74,7 +73,7 @@ GnomeUIInfo the_file_menu[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 		GNOME_APP_UI_ITEM, N_("Aut_otranslate..."),
-		N_("Autotranslate the file with information from the default query domain/learn buffer"),
+		N_("Autotranslate the file with information from your learn buffer"),
 		gtranslator_auto_translation_dialog, NULL, NULL,
 		GNOME_APP_PIXMAP_DATA, auto_translation_xpm,
 		GDK_F10, 0, NULL
@@ -84,7 +83,7 @@ GnomeUIInfo the_file_menu[] = {
 		GNOME_APP_UI_ITEM, N_("Remove all translations..."),
 		N_("Remove all existing translations from the po file"),
 		gtranslator_remove_all_translations_dialog, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_OPEN,
+		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_TRASH,
 		0, 0, NULL
 	},
 	GNOMEUIINFO_SEPARATOR,
@@ -151,27 +150,27 @@ GnomeUIInfo the_edit_menu[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 		GNOME_APP_UI_ITEM, N_("_Header..."),
-		N_("Edit the header"),
+		N_("Edit po file header"),
 		gtranslator_header_edit_dialog, NULL, NULL,
 		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP,
 		GDK_F8, 0, NULL
 	},
-	GNOMEUIINFO_END
-};
-
-GnomeUIInfo the_views_menu[] = {
-	GNOMEUIINFO_RADIOITEM_DATA(N_("_Message"),
-		N_("Standard messages view"),
-		gtranslator_switch_views, GINT_TO_POINTER(GTR_MESSAGE_VIEW), NULL),
-	GNOMEUIINFO_RADIOITEM_DATA(N_("_Numbers"),
-		N_("View numbers in the message"),
-		gtranslator_switch_views, GINT_TO_POINTER(GTR_NUMBER_VIEW), NULL),
-	GNOMEUIINFO_RADIOITEM_DATA(N_("C _Formats"),
-		N_("View C formats of the message"),
-		gtranslator_switch_views, GINT_TO_POINTER(GTR_C_FORMAT_VIEW), NULL),
-	GNOMEUIINFO_RADIOITEM_DATA(N_("_Hotkeys"),
-		N_("View hotkeys in the message"),
-		gtranslator_switch_views, GINT_TO_POINTER(GTR_HOTKEY_VIEW), NULL),
+	GNOMEUIINFO_SEPARATOR,
+	{
+		GNOME_APP_UI_ITEM, N_("C_omment..."),
+		N_("Edit message comment"),
+		gtranslator_edit_comment_dialog, NULL, NULL,
+		GNOME_APP_PIXMAP_DATA, edit_comment_xpm,
+		GDK_F9, 0, NULL
+	},
+	GNOMEUIINFO_SEPARATOR,
+	{
+		GNOME_APP_UI_ITEM, N_("Copy _message -> translation"),
+		N_("Copy the original message contents and paste them as translation"),
+		gtranslator_message_status_set_sticky, NULL, NULL,
+		GNOME_APP_PIXMAP_DATA, copy_msgid2msgstr_xpm,
+		GDK_F11, 0, NULL
+	},
 	GNOMEUIINFO_END
 };
 
@@ -249,31 +248,27 @@ GnomeUIInfo the_msg_status_menu[] = {
 		GNOME_APP_PIXMAP_FILENAME, "gtranslator/fuzzy_small.png",
 		GDK_2, GDK_MOD1_MASK, NULL
 	},
-	{
-		GNOME_APP_UI_TOGGLEITEM, N_("_Stick"),
-		N_("Stick this message"),
-		gtranslator_message_change_status,
-		GINT_TO_POINTER(GTR_MSG_STATUS_STICK),
-		NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_COPY,
-		GDK_3, GDK_MOD1_MASK, NULL
-	},
+	GNOMEUIINFO_END
+};
+
+GnomeUIInfo the_colorschemes_menu[] = {
 	GNOMEUIINFO_END
 };
 
 GnomeUIInfo the_settings_menu[] = {
 	GNOMEUIINFO_MENU_PREFERENCES_ITEM(gtranslator_preferences_dialog_create, NULL),
+	GNOMEUIINFO_SEPARATOR,
+	GNOMEUIINFO_SUBTREE(N_("_Colorschemes"), the_colorschemes_menu),
 	GNOMEUIINFO_END
 };
 
 GnomeUIInfo the_help_menu[] = {
 	GNOMEUIINFO_HELP("gtranslator"),
-	GNOMEUIINFO_MENU_ABOUT_ITEM(gtranslator_about_dialog, NULL),
-	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_ITEM_STOCK(N_("gtranslator _website"),
 			       N_("gtranslator's homepage on the web"),
 			       gtranslator_utils_show_home_page,
 			       GNOME_STOCK_MENU_HOME),
+	GNOMEUIINFO_MENU_ABOUT_ITEM(gtranslator_about_dialog, NULL),
 	GNOMEUIINFO_END
 };
 
@@ -311,15 +306,6 @@ GnomeUIInfo the_toolbar[] = {
 			       N_("Undo the last performed action"),
 			       gtranslator_actions_undo,
 			       GNOME_STOCK_PIXMAP_UNDO),
-	GNOMEUIINFO_SEPARATOR,
-	GNOMEUIINFO_ITEM_STOCK(N_("Options"),
-			       N_("gtranslator options"),
-			       gtranslator_preferences_dialog_create,
-			       GNOME_STOCK_PIXMAP_PREFERENCES),
-	GNOMEUIINFO_ITEM_STOCK(N_("Exit"),
-			       N_("Exit"),
-			       gtranslator_quit,
-			       GNOME_STOCK_PIXMAP_EXIT),
 	GNOMEUIINFO_END
 };
 
