@@ -1,5 +1,5 @@
 /*
- * (C) 2000-2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2000-2002 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  * 
  * gtranslator is free software; you can redistribute it and/or modify
@@ -31,8 +31,6 @@
  */
 struct {
 	guint warn_if_fuzzy		: 1;
-	guint warn_if_no_change		: 1;
-	guint dont_save_unchanged_files : 1;
 	guint save_geometry		: 1;
 	guint unmark_fuzzy		: 1;
 	
@@ -45,10 +43,10 @@ struct {
 	guint load_backends		: 1;
 	guint fuzzy_matching		: 1;
 	guint auto_learn		: 1;
-	guint show_sidebar		: 1;
 	guint show_messages_table	: 1;
 	guint show_comment		: 1;
 	guint collapse_translated	: 1;
+	guint check_formats		: 1;
 
 	/*
 	 * Special options, taken by value in the prefs-box.
@@ -56,6 +54,7 @@ struct {
 	guint fill_header		: 1;
 	guint update_function		: 1;
 	guint rambo_function		: 1;
+	guint highlight			: 1;
 	guint dot_char			: 1;
 	guint popup_menu		: 1;
 	guint check_recent_file		: 1;
